[![badge doc](https://img.shields.io/badge/docs-v5.0.0-orange.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.pad.face/v5.0.0/sphinx/index.html)
[![badge pipeline](https://gitlab.idiap.ch/bob/bob.pad.face/badges/v5.0.0/pipeline.svg)](https://gitlab.idiap.ch/bob/bob.pad.face/commits/v5.0.0)
[![badge coverage](https://gitlab.idiap.ch/bob/bob.pad.face/badges/v5.0.0/coverage.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.pad.face/v5.0.0/coverage/)
[![badge gitlab](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/bob/bob.pad.face)

# Face presentation attack detection (anti-spoofing)

This package is part of the signal-processing and machine learning toolbox
[Bob](https://www.idiap.ch/software/bob). It implements tools for spoofing or
presentation attack detection in face biometrics.

## Installation

Follow our
[installation instructions](https://www.idiap.ch/software/bob/install). Then,
to install this package, run:

``` sh
conda install bob.pad.face
```

## Contact

For questions or reporting issues to this software package, contact our
development [mailing list](https://www.idiap.ch/software/bob/discuss).
